@@ -36,6 +36,7 @@ typedef struct _RegionWidget RegionWidget;
 typedef struct Channel Channel;
 typedef struct Track Track;
 typedef struct Region AudioRegion;
+typedef struct AudioClip AudioClip;
 
 /**
  * @addtogroup audio
@@ -46,8 +47,11 @@ typedef struct Region AudioRegion;
 /**
  * Creates a Region for audio data.
  *
- * @param add_to_project Add Region to project
- *   registry. This should be false when cloning.
+ * FIXME First create the
+ * audio on the pool and then pass the pool id here.
+ *
+ * @param pool_id The pool ID. This is used when
+ *   creating clone regions (non-main).
  * @param filename Filename, if loading from
  *   file, otherwise NULL.
  * @param frames Float array, if loading from
@@ -56,6 +60,7 @@ typedef struct Region AudioRegion;
  */
 AudioRegion *
 audio_region_new (
+  const int        pool_id,
   const char *     filename,
   const float *    frames,
   const long       nframes,
@@ -63,6 +68,14 @@ audio_region_new (
   const Position * start_pos,
   const int        is_main);
 
+/**
+ * Returns the audio clip associated with the
+ * Region.
+ */
+AudioClip *
+audio_region_get_clip (
+  const Region * self);
+
 /**
  * Frees members only but not the audio region itself.
  *
