@@ -49,13 +49,12 @@
  * @{
  */
 
-#define MASTER_POS -1 /* master channel special position */
 #define FOREACH_STRIP for (int i = 0; i < STRIP_SIZE; i++)
 #define FOREACH_AUTOMATABLE(ch) for (int i = 0; i < ch->num_automatables; i++)
 #define MAX_FADER_AMP 1.42f
 #define channel_get_fader_automatable(ch) \
-  channel_get_automatable (ch, \
-                           AUTOMATABLE_TYPE_CHANNEL_FADER)
+  channel_get_automatable (\
+    ch, AUTOMATABLE_TYPE_CHANNEL_FADER)
 
 typedef struct _ChannelWidget ChannelWidget;
 typedef struct Track Track;
@@ -118,6 +117,44 @@ typedef struct Channel
    * found. */
   int               all_midi_ins;
 
+  /**
+   * External audio L inputs that are currently
+   * connected to this channel as official inputs,
+   * unless all_stereo_l_ins is enabled.
+   *
+   * These should be serialized every time and
+   * if all_stereo_l_ins is not enabled, connected to
+   * when the project gets loaded.
+   *
+   * If all_stereo_l_ins is enabled, these are
+   * ignored.
+   */
+  ExtPort *         ext_stereo_l_ins[32];
+  int               num_ext_stereo_l_ins;
+
+  /** If 1, the channel will connect to all
+   * stereo L ins found. */
+  int               all_stereo_l_ins;
+
+  /**
+   * External audio R inputs that are currently
+   * connected to this channel as official inputs,
+   * unless all_stereo_r_ins is enabled.
+   *
+   * These should be serialized every time and
+   * if all_stereo_r_ins is not enabled, connected to
+   * when the project gets loaded.
+   *
+   * If all_stereo_r_ins is enabled, these are
+   * ignored.
+   */
+  ExtPort *         ext_stereo_r_ins[32];
+  int               num_ext_stereo_r_ins;
+
+  /** If 1, the channel will connect to all
+   * stereo R ins found. */
+  int               all_stereo_r_ins;
+
   /**
    * 1 or 0 flags for each channel to enable it or
    * disable it.
@@ -142,30 +179,6 @@ typedef struct Channel
    */
   PassthroughProcessor prefader;
 
-  /**
-   * L & R audio input ports.
-   */
-  StereoPorts *    stereo_in;
-
-  /**
-   * MIDI input for receiving MIDI signals from
-   * the piano roll (i.e., MIDI notes inside
-   * regions) or other sources.
-   */
-  Port *           piano_roll;
-
-  /**
-   * MIDI in port ID.
-   *
-   * This port is for receiving MIDI signals from
-   * an external MIDI source.
-   *
-   * This is also where piano roll, midi in and midi
-   * manual press will be routed to and this will
-   * be the port used to pass midi to the plugins.
-   */
-  Port *           midi_in;
-
   /**
    * MIDI output for sending MIDI signals to other
    * destinations, such as other channels when
@@ -173,9 +186,6 @@ typedef struct Channel
    */
   Port *           midi_out;
 
-  /** Flag used while processing. */
-  int              filled_stereo_in_bufs;
-
   /*
    * Ports for direct (track-to-track) routing with
    * the exception of master, which will route the
@@ -221,24 +231,9 @@ channel_fields_schema[] =
     "fader", CYAML_FLAG_DEFAULT,
     Channel, fader, fader_fields_schema),
 	CYAML_FIELD_MAPPING_PTR (
-    "stereo_in",
-    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
-    Channel, stereo_in,
-    stereo_ports_fields_schema),
-	CYAML_FIELD_MAPPING_PTR (
-    "midi_in",
-    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
-    Channel, midi_in,
-    port_fields_schema),
-	CYAML_FIELD_MAPPING_PTR (
     "midi_out",
     CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
     Channel, midi_out,
-    port_fields_schema),
-	CYAML_FIELD_MAPPING_PTR (
-    "piano_roll",
-    CYAML_FLAG_POINTER | CYAML_FLAG_OPTIONAL,
-    Channel, piano_roll,
     port_fields_schema),
 	CYAML_FIELD_MAPPING_PTR (
     "stereo_out",
@@ -259,6 +254,20 @@ channel_fields_schema[] =
     "midi_channels", CYAML_FLAG_DEFAULT,
     Channel, midi_channels,
     &int_schema, 16),
+  CYAML_FIELD_SEQUENCE_COUNT (
+    "ext_stereo_l_ins", CYAML_FLAG_DEFAULT,
+    Channel, ext_stereo_l_ins, num_ext_stereo_l_ins,
+    &ext_port_schema, 0, CYAML_UNLIMITED),
+  CYAML_FIELD_INT (
+    "all_stereo_l_ins", CYAML_FLAG_DEFAULT,
+    Channel, all_stereo_l_ins),
+  CYAML_FIELD_SEQUENCE_COUNT (
+    "ext_stereo_r_ins", CYAML_FLAG_DEFAULT,
+    Channel, ext_stereo_r_ins, num_ext_stereo_r_ins,
+    &ext_port_schema, 0, CYAML_UNLIMITED),
+  CYAML_FIELD_INT (
+    "all_stereo_r_ins", CYAML_FLAG_DEFAULT,
+    Channel, all_stereo_r_ins),
   CYAML_FIELD_INT (
     "all_midi_channels", CYAML_FLAG_DEFAULT,
     Channel, all_midi_channels),
@@ -278,10 +287,20 @@ void
 channel_init_loaded (Channel * channel);
 
 /**
- * Handles the recording logic inside the process cycle.
+ * Handles the recording logic inside the process
+ * cycle.
+ *
+ * The MidiEvents are already dequeued at this
+ * point.
+ *
+ * @param g_frames_start Global start frames.
+ * @param nframes Number of frames to process.
  */
 void
-channel_handle_recording (Channel * self);
+channel_handle_recording (
+  Channel *       self,
+  const long      g_frames_start,
+  const nframes_t nframes);
 
 /**
  * Appends all channel ports and optionally
@@ -442,7 +461,15 @@ channel_reconnect_ext_input_ports (
  * Returns the index of the last active slot.
  */
 int
-channel_get_last_active_slot_index (Channel * channel);
+channel_get_last_active_slot_index (
+  Channel * channel);
+
+/**
+ * Returns the last Plugin in the strip.
+ */
+Plugin *
+channel_get_last_plugin (
+  Channel * self);
 
 /**
  * Returns the index on the mixer.
