@@ -324,6 +324,13 @@ position_from_frames (
     pos, frames);
 }
 
+/**
+ * Returns the Position in milliseconds.
+ */
+long
+position_to_ms (
+  const Position * pos);
+
 /**
  * Compares 2 positions.
  *
