@@ -314,6 +314,14 @@ typedef struct Region
 
   /* ==== CHORD REGION END ==== */
 
+  /**
+   * Current lane for this Region.
+   *
+   * Used in live operations temporarily and in
+   * the widgets for positioning if it's non-NULL.
+   */
+  TrackLane *        tmp_lane;
+
   /**
    * Info on whether this Region is transient/lane
    * and pointers to transient/lane equivalents.
@@ -395,8 +403,8 @@ static const cyaml_schema_field_t
 
 static const cyaml_schema_value_t
 region_schema = {
-	CYAML_VALUE_MAPPING (CYAML_FLAG_POINTER,
-			Region, region_fields_schema),
+  CYAML_VALUE_MAPPING (CYAML_FLAG_POINTER,
+    Region, region_fields_schema),
 };
 
 ARRANGER_OBJ_DECLARE_MOVABLE_W_LENGTH (
@@ -580,8 +588,6 @@ region_get_num_loops (
   Region * region,
   int      count_incomplete_loops);
 
-/* TODO shift by delta number of tracks */
-
 /**
  * Sets the track lane.
  */
@@ -590,6 +596,45 @@ region_set_lane (
   Region * region,
   TrackLane * lane);
 
+/**
+ * Moves the given Region to the given TrackLane.
+ *
+ * Works with TrackLane's of other Track's as well.
+ *
+ * Maintains the selection status of the
+ * Region.
+ *
+ * Assumes that the Region is already in a
+ * TrackLane.
+ *
+ * @param tmp If the Region should be moved
+ *   temporarily (the tmp_lane member will be used
+ *   instead of actually moving).
+ */
+void
+region_move_to_lane (
+  Region *    region,
+  TrackLane * lane,
+  const int   tmp);
+
+/**
+ * Moves the Region to the given Track, maintaining
+ * the selection status of the Region and the
+ * TrackLane position.
+ *
+ * Assumes that the Region is already in a
+ * TrackLane.
+ *
+ * @param tmp If the Region should be moved
+ *   temporarily (the tmp_lane member will be used
+ *   instead of actually moving).
+ */
+void
+region_move_to_track (
+  Region *  region,
+  Track *   track,
+  const int tmp);
+
 /**
  * Sets the automation track.
  */
