@@ -34,6 +34,7 @@
 #include "audio/scale.h"
 #include "audio/scale_object.h"
 #include "audio/track_lane.h"
+#include "audio/track_processor.h"
 #include "utils/yaml.h"
 
 #include <gtk/gtk.h>
@@ -221,6 +222,9 @@ typedef struct Track
   /** MIDI channel (MIDI/Instrument track only). */
   uint8_t             midi_ch;
 
+  /** Region currently recording on. */
+  Region *            recording_region;
+
   /* ==== INSTRUMENT/MIDI/AUDIO TRACK END ==== */
 
   /* ==== CHORD TRACK ==== */
@@ -260,6 +264,14 @@ typedef struct Track
 
   /* ==== CHANNEL TRACK END ==== */
 
+  /**
+   * The TrackProcessor, used for processing.
+   *
+   * This is the starting point when processing
+   * a Track.
+   */
+  TrackProcessor      processor;
+
   AutomationTracklist automation_tracklist;
 
   /** Modulators for this Track. */
@@ -365,6 +377,10 @@ track_fields_schema[] =
     CYAML_FLAG_DEFAULT | CYAML_FLAG_OPTIONAL,
     Track, channel,
     channel_fields_schema),
+  CYAML_FIELD_MAPPING (
+    "processor", CYAML_FLAG_DEFAULT,
+    Track, processor,
+    track_processor_fields_schema),
   CYAML_FIELD_MAPPING (
     "automation_tracklist", CYAML_FLAG_DEFAULT,
     Track, automation_tracklist,
@@ -488,7 +504,8 @@ track_add_region (
   Region *          region,
   AutomationTrack * at,
   int               lane_pos,
-  int               gen_name);
+  int               gen_name,
+  int               fire_events);
 
 /**
  * Writes the track to the given MIDI file.
@@ -519,9 +536,10 @@ track_select (
  */
 void
 track_remove_region (
-  Track * track,
+  Track *  track,
   Region * region,
-  int     free);
+  int      fire_events,
+  int      free);
 
 /**
  * Returns the region at the given position, or NULL.
@@ -646,6 +664,23 @@ track_add_modulator (
   Track * track,
   Modulator * modulator);
 
+/**
+ * Returns if regions in tracks from type1 can
+ * be moved to type2.
+ */
+static inline int
+track_type_is_compatible_for_moving (
+  const TrackType type1,
+  const TrackType type2)
+{
+  return
+    type1 == type2 ||
+    (type1 == TRACK_TYPE_MIDI &&
+     type2 == TRACK_TYPE_INSTRUMENT) ||
+    (type1 == TRACK_TYPE_INSTRUMENT &&
+     type2 == TRACK_TYPE_MIDI);
+}
+
 /**
  * Updates the frames of each position in each child
  * of the track recursively.
@@ -670,6 +705,22 @@ PassthroughProcessorType
 track_get_passthrough_processor_type (
   const Track * track);
 
+/**
+ * Creates missing TrackLane's until pos.
+ */
+void
+track_create_missing_lanes (
+  Track *   track,
+  const int pos);
+
+/**
+ * Removes the empty last lanes of the Track
+ * (except the last one).
+ */
+void
+track_remove_empty_last_lanes (
+  Track * track);
+
 /**
  * Wrapper for each track type.
  */
