@@ -69,7 +69,7 @@ typedef struct TrackLane
   /** Regions in this track. */
   Region **           regions;
   int                 num_regions;
-  int                 regions_size;
+  size_t              regions_size;
 
   /** Pointer back to the owner Track. */
   Track *             track;
@@ -77,8 +77,13 @@ typedef struct TrackLane
   /** Position of owner Track in the Tracklist. */
   int                 track_pos;
 
-  /** MIDI channel, if MIDI lane, starting at 1. */
-  int                 midi_ch;
+  /**
+   * MIDI channel, if MIDI lane, starting at 1.
+   *
+   * If this is set to 0, the value will be
+   * inherited from the Track.
+   */
+  uint8_t             midi_ch;
 
 } TrackLane;
 
@@ -108,6 +113,9 @@ track_lane_fields_schema[] =
 	CYAML_FIELD_INT (
     "track_pos", CYAML_FLAG_DEFAULT,
     TrackLane, track_pos),
+	CYAML_FIELD_UINT (
+    "midi_ch", CYAML_FLAG_DEFAULT,
+    TrackLane, midi_ch),
 
 	CYAML_FIELD_END
 };
