@@ -33,11 +33,11 @@
 
 #define AUDIO_GROUP_TRACK_WIDGET_TYPE \
   (audio_group_track_widget_get_type ())
-G_DECLARE_FINAL_TYPE (AudioGroupTrackWidget,
-                      audio_group_track_widget,
-                      Z,
-                      AUDIO_GROUP_TRACK_WIDGET,
-                      TrackWidget)
+G_DECLARE_FINAL_TYPE (
+  AudioGroupTrackWidget,
+  audio_group_track_widget,
+  Z, AUDIO_GROUP_TRACK_WIDGET,
+  TrackWidget)
 
 typedef struct _AutomationTracklistWidget
   AutomationTracklistWidget;
@@ -71,4 +71,3 @@ audio_group_track_widget_refresh_buttons (
   AudioGroupTrackWidget * self);
 
 #endif
-
