@@ -55,8 +55,8 @@ io_mkdir (const char * dir);
 /**
  * Gets home dir. MUST be freed.
  */
-char *
-io_get_home_dir ();
+const char *
+io_get_home_dir (void);
 
 /**
  * Creates the file if doesn't exist
