@@ -35,11 +35,11 @@
 #include <gtk/gtk.h>
 
 #define ZRYTHM_APP_TYPE (zrythm_app_get_type ())
-G_DECLARE_FINAL_TYPE (ZrythmApp,
-                      zrythm_app,
-                      ZRYTHM,
-                      APP,
-                      GtkApplication)
+G_DECLARE_FINAL_TYPE (
+  ZrythmApp,
+  zrythm_app,
+  ZRYTHM, APP,
+  GtkApplication)
 
 typedef struct _MainWindowWidget MainWindowWidget;
 typedef struct Project Project;
