@@ -129,12 +129,28 @@ action_disable_app_action (
 }
 
 void
-activate_manual (GSimpleAction *action,
-                GVariant      *variant,
-                gpointer       user_data)
+activate_news (
+  GSimpleAction *action,
+  GVariant      *variant,
+  gpointer       user_data)
+{
+  gtk_show_uri_on_window (
+    GTK_WINDOW (MAIN_WINDOW),
+    "https://git.zrythm.org/cgit/zrythm/plain/"
+    "CHANGELOG.md",
+    0,
+    NULL);
+}
+
+void
+activate_manual (
+  GSimpleAction *action,
+  GVariant      *variant,
+  gpointer       user_data)
 {
 #ifdef MANUAL_PATH
   UiLanguage lang =
+    (UiLanguage)
     g_settings_get_enum (
       S_PREFERENCES,
       "language");
@@ -438,7 +454,7 @@ activate_original_size (GSimpleAction *action,
 {
   RULER_WIDGET_GET_PRIVATE (
     Z_RULER_WIDGET (MW_RULER));
-  rw_prv->zoom_level = DEFAULT_ZOOM_LEVEL;
+  rw_prv->zoom_level = (double) DEFAULT_ZOOM_LEVEL;
 
   EVENTS_PUSH (ET_TIMELINE_VIEWPORT_CHANGED,
                NULL);
@@ -1084,6 +1100,22 @@ activate_goto_next_marker (
     TRANSPORT);
 }
 
+void
+activate_play_pause (
+  GSimpleAction *action,
+  GVariant      *variant,
+  gpointer       user_data)
+{
+  if (TRANSPORT_IS_ROLLING)
+    {
+      transport_request_pause (TRANSPORT);
+    }
+  else if (TRANSPORT_IS_PAUSED)
+    {
+      transport_request_roll (TRANSPORT);
+    }
+}
+
 void
 activate_delete_selected_tracks (
   GSimpleAction *action,
