@@ -34,8 +34,11 @@
 /**
  * Creates a Region for audio data.
  *
- * @param add_to_project Add Region to project
- *   registry. This should be false when cloning.
+ * FIXME First create the
+ * audio on the pool and then pass the pool id here.
+ *
+ * @param pool_id The pool ID. This is used if not
+ *   -1.
  * @param filename Filename, if loading from
  *   file, otherwise NULL.
  * @param frames Float array, if loading from
@@ -44,6 +47,7 @@
  */
 AudioRegion *
 audio_region_new (
+  const int        pool_id,
   const char *     filename,
   const float *    frames,
   const long       nframes,
@@ -58,38 +62,80 @@ audio_region_new (
   self->pool_id = -1;
 
   AudioClip * clip = NULL;
-  if (filename)
-    clip =
-      audio_clip_new_from_file (filename);
-  else
-    clip =
-      audio_clip_new_from_float_array (
-        frames, nframes, channels, "new audio clip");
-  g_return_val_if_fail (clip, NULL);
+  int recording = 0;
+  if (pool_id == -1)
+    {
+      if (filename)
+        {
+          clip =
+            audio_clip_new_from_file (filename);
+        }
+      else if (frames)
+        {
+          clip =
+            audio_clip_new_from_float_array (
+              frames, nframes, channels,
+              "new audio clip");
+        }
+      else
+        {
+          clip =
+            audio_clip_new_recording (
+              2, nframes, "new recording clip");
+          recording = 1;
+        }
+      g_return_val_if_fail (clip, NULL);
 
-  self->pool_id =
-    audio_pool_add_clip (
-      AUDIO_POOL, clip);
-  g_warn_if_fail (self->pool_id > -1);
+      self->pool_id =
+        audio_pool_add_clip (
+          AUDIO_POOL, clip);
+      g_warn_if_fail (self->pool_id > -1);
+    }
+  else
+    {
+      self->pool_id = pool_id;
+      clip =
+          AUDIO_POOL->clips[pool_id];
+      g_warn_if_fail (clip && clip->frames);
+    }
 
   /* set end pos to sample end */
-  position_set_to_pos (&self->end_pos,
-                       &self->start_pos);
-  position_add_frames (&self->end_pos,
-                       clip->num_frames);
+  position_set_to_pos (
+    &self->end_pos, start_pos);
+  position_add_frames (
+    &self->end_pos, clip->num_frames);
 
   /* init */
-  region_init ((Region *) self,
-               start_pos,
-               &self->end_pos,
-               is_main);
+  region_init (
+    self, start_pos, &self->end_pos, is_main);
 
-  if (is_main)
+  if (is_main && !recording)
     audio_clip_write_to_pool (clip);
 
   return self;
 }
 
+/**
+ * Returns the audio clip associated with the
+ * Region.
+ */
+AudioClip *
+audio_region_get_clip (
+  const Region * self)
+{
+  g_return_val_if_fail (
+    self->pool_id >= 0 &&
+    self->type == REGION_TYPE_AUDIO,
+    NULL);
+
+  AudioClip * clip =
+    AUDIO_POOL->clips[self->pool_id];
+
+  g_return_val_if_fail (clip, NULL);
+
+  return clip;
+}
+
 /**
  * Frees members only but not the audio region itself.
  *
