@@ -205,10 +205,12 @@ engine_init (
     }
 
   self->pan_law =
+    (PanLaw)
     g_settings_get_enum (
       S_PREFERENCES,
       "pan-law");
   self->pan_algo =
+    (PanAlgorithm)
     g_settings_get_enum (
       S_PREFERENCES,
       "pan-algo");
@@ -259,6 +261,8 @@ engine_init (
 
       self->audio_backend =
         AUDIO_BACKEND_DUMMY;
+      self->midi_backend =
+        MIDI_BACKEND_DUMMY;
       engine_dummy_setup (self, loading);
     }
 
@@ -314,7 +318,7 @@ engine_init (
             "backend. Will use the dummy backend "
             "instead. Please check your backend "
             "settings in the Preferences."),
-          engine_audio_backend_to_string (
+          engine_midi_backend_to_string (
             self->midi_backend));
       ui_show_message_full (
         GTK_WINDOW (MAIN_WINDOW),
@@ -883,7 +887,7 @@ engine_process (
     {
       /* queue metronome if met within this cycle */
       if (TRANSPORT->metronome_enabled &&
-          IS_TRANSPORT_ROLLING)
+          TRANSPORT_IS_ROLLING)
         {
           queue_metronome_events (
             self, _nframes - nframes, nframes);
@@ -936,7 +940,7 @@ engine_post_process (
 
   /* move the playhead if rolling and not
    * pre-rolling */
-  if (IS_TRANSPORT_ROLLING &&
+  if (TRANSPORT_IS_ROLLING &&
       self->remaining_latency_preroll == 0)
     {
       transport_add_to_playhead (
