@@ -277,11 +277,11 @@ midi_note_set_val (
   /* if currently playing set a note off event. */
   if (midi_note_hit (
         midi_note, PLAYHEAD->frames) &&
-      IS_TRANSPORT_ROLLING)
+      TRANSPORT_IS_ROLLING)
     {
       MidiEvents * midi_events =
         region_get_track (midi_note->region)->
-          channel->piano_roll->midi_events;
+          processor.piano_roll->midi_events;
 
       zix_sem_wait (&midi_events->access_sem);
       midi_events_add_note_off (
