@@ -80,7 +80,7 @@ midi_track_fill_midi_events (
   nframes_t     nframes,
   MidiEvents *      midi_events)
 {
-  int i, j, k, jj, num_loops;
+  int i, j, k, jj, kk, num_loops;
   long g_end_frames;
   long local_pos, local_end_pos;
   long loop_start_adjusted,
@@ -255,12 +255,12 @@ midi_track_fill_midi_events (
                * reached within this cycle */
               if (loop_point_met && k == 0)
                 {
-                  for (i = 0;
-                       i < region->num_midi_notes;
-                       i++)
+                  for (kk = 0;
+                       kk < region->num_midi_notes;
+                       kk++)
                     {
                       midi_note =
-                        region->midi_notes[i];
+                        region->midi_notes[kk];
 
                       /* FIXME check if note is on
                        * first */
@@ -275,6 +275,9 @@ midi_track_fill_midi_events (
                         (midi_time_t)
                         (diff_to_loop_end - 1),
                         1);
+                      g_warn_if_fail (
+                        diff_to_loop_end - 1 <
+                        local_start_frame + nframes);
                     }
                 }
               /* send all MIDI notes off if end of
@@ -285,12 +288,12 @@ midi_track_fill_midi_events (
                   region_end_adjusted <=
                     local_end_pos)
                 {
-                  for (i = 0;
-                       i < region->num_midi_notes;
-                       i++)
+                  for (kk = 0;
+                       kk < region->num_midi_notes;
+                       kk++)
                     {
                       midi_note =
-                        region->midi_notes[i];
+                        region->midi_notes[kk];
 
                       mn_start_frames =
                         midi_note->start_pos.frames;
@@ -318,6 +321,11 @@ midi_track_fill_midi_events (
                             (region_end_adjusted -
                               local_pos),
                             1);
+                          g_warn_if_fail (
+                            region_end_adjusted -
+                              local_pos <
+                            local_start_frame +
+                              nframes);
                         }
                     }
                 }
@@ -329,12 +337,12 @@ midi_track_fill_midi_events (
                        region_end_frames <
                          g_end_frames)
                 {
-                  for (i = 0;
-                       i < region->num_midi_notes;
-                       i++)
+                  for (kk = 0;
+                       kk < region->num_midi_notes;
+                       kk++)
                     {
                       midi_note =
-                        region->midi_notes[i];
+                        region->midi_notes[kk];
 
                       mn_start_frames =
                         midi_note->start_pos.frames;
@@ -380,6 +388,12 @@ midi_track_fill_midi_events (
                             ((region_end_frames - 1) -
                               g_start_frames),
                             1);
+                          g_warn_if_fail (
+                            (region_end_frames -
+                               1) -
+                               g_start_frames <
+                            local_start_frame +
+                              nframes);
                         }
                     }
                   continue;
@@ -388,12 +402,12 @@ midi_track_fill_midi_events (
                * will be back to the loop start) */
               else if (local_end_pos <= local_pos)
                 {
-                  for (i = 0;
-                       i < region->num_midi_notes;
-                       i++)
+                  for (kk = 0;
+                       kk < region->num_midi_notes;
+                       kk++)
                     {
                       midi_note =
-                        region->midi_notes[i];
+                        region->midi_notes[kk];
 
                       mn_start_frames =
                         midi_note->start_pos.frames;
@@ -428,6 +442,12 @@ midi_track_fill_midi_events (
                               local_pos) +
                               diff_to_loop_end),
                             1);
+                          g_warn_if_fail (
+                            ((loop_end_adjusted -
+                              local_pos) +
+                              diff_to_loop_end) <
+                            local_start_frame +
+                              nframes);
                         }
                     }
                 }
@@ -436,12 +456,12 @@ midi_track_fill_midi_events (
               local_pos -= clip_start_frames;
               local_end_pos -= clip_start_frames;
 
-              for (i = 0;
-                   i < region->num_midi_notes;
-                   i++)
+              for (kk = 0;
+                   kk < region->num_midi_notes;
+                   kk++)
                 {
                   midi_note =
-                    region->midi_notes[i];
+                    region->midi_notes[kk];
 
                   mn_start_frames =
                     midi_note->start_pos.frames;
@@ -529,6 +549,12 @@ midi_track_fill_midi_events (
                            local_pos) +
                           diff_to_loop_end),
                         1);
+                      g_warn_if_fail (
+                        ((mn_end_frames -
+                           local_pos) +
+                          diff_to_loop_end) <
+                        local_start_frame +
+                          nframes);
                     }
                 }
             }
