@@ -283,6 +283,23 @@ position_add_frames (
   pos->frames = new_frames;
 }
 
+/**
+ * Returns the Position in milliseconds.
+ */
+long
+position_to_ms (
+  const Position * pos)
+{
+  if (position_to_frames (pos) == 0)
+    {
+      return 0;
+    }
+  return
+    (long)
+    ((1000.0 * (double) position_to_frames (pos)) /
+     ((double) AUDIO_ENGINE->sample_rate));
+}
+
 /**
  * Compares 2 positions.
  *
@@ -477,7 +494,9 @@ position_snap (
  * TODO
  */
 void
-position_from_seconds (Position * position, double secs)
+position_from_seconds (
+  Position * position,
+  double secs)
 {
   /*AUDIO_ENGINE->frames_per_tick;*/
   /*AUDIO_ENGINE->sample_rate;*/
