@@ -73,18 +73,23 @@ region_init (
   const Position * end_pos,
   const int        is_main)
 {
-  position_set_to_pos (&self->start_pos,
-                       start_pos);
-  position_set_to_pos (&self->end_pos,
-                       end_pos);
+  position_set_to_pos (
+    &self->start_pos, start_pos);
+  self->start_pos.frames = start_pos->frames;
+  position_set_to_pos (
+    &self->end_pos, end_pos);
+  self->end_pos.frames = end_pos->frames;
   position_init (&self->clip_start_pos);
   long length =
-    region_get_full_length_in_ticks (self);
-  position_from_ticks (&self->true_end_pos,
-                       length);
+    region_get_full_length_in_frames (self);
+  position_from_frames (
+    &self->true_end_pos, length);
   position_init (&self->loop_start_pos);
-  position_set_to_pos (&self->loop_end_pos,
-                       &self->true_end_pos);
+  position_set_to_pos (
+    &self->loop_end_pos,
+    &self->true_end_pos);
+  self->loop_end_pos.frames =
+    self->true_end_pos.frames;
   self->linked_region_name = NULL;
 
   if (is_main)
@@ -122,6 +127,164 @@ region_set_lane (
     }
 }
 
+/**
+ * @param track Track to use for getting the lane.
+ *   If this is NULL, lane is used.
+ * @param lane Lane to use. If this is NULL,
+ *   track is used.
+ */
+static void
+set_tmp_lane_to_visible_counterparts (
+  Region *    region,
+  Track *     track,
+  TrackLane * lane)
+{
+#define SET_IF_VISIBLE(x) \
+  region = \
+    region_get_##x##_region (region); \
+  if ( \
+    arranger_object_info_should_be_visible ( \
+      &region->obj_info)) \
+    { \
+      region->tmp_lane = \
+        track ? \
+          track->lanes[region->lane_pos] : \
+          lane; \
+    }
+
+  SET_IF_VISIBLE (main);
+  SET_IF_VISIBLE (lane);
+
+#undef SET_IF_VISIBLE
+}
+
+/**
+ * Moves the Region to the given Track, maintaining
+ * the selection status of the Region and the
+ * TrackLane position.
+ *
+ * Assumes that the Region is already in a
+ * TrackLane.
+ *
+ * @param tmp If the Region should be moved
+ *   temporarily (the tmp_lane member will be used
+ *   instead of actually moving).
+ */
+void
+region_move_to_track (
+  Region *  region,
+  Track *   track,
+  const int tmp)
+{
+  g_return_if_fail (region && track);
+
+  Track * region_track =
+    region_get_track (region);
+  g_return_if_fail (region_track);
+
+  if (tmp)
+    {
+      /* create lanes if they don't exist */
+      track_create_missing_lanes (
+        track, region->lane_pos);
+
+      set_tmp_lane_to_visible_counterparts (
+        region, track, NULL);
+    }
+  else
+    {
+      if (region_track == track)
+        return;
+
+      int selected = region_is_selected (region);
+
+      /* create lanes if they don't exist */
+      track_create_missing_lanes (
+        track, region->lane_pos);
+
+      /* remove the region from its old track */
+      track_remove_region (
+        region_track,
+        region, F_NO_PUBLISH_EVENTS, F_NO_FREE);
+
+      /* add the region to its new track */
+      track_add_region (
+        track, region, NULL,
+        region->lane_pos, F_NO_GEN_NAME,
+        F_NO_PUBLISH_EVENTS);
+      region_set_lane (
+        region, track->lanes[region->lane_pos]);
+
+      /* reselect if necessary */
+      region_select (
+        region, selected);
+
+      /* remove empty lanes if the region was the
+       * last on its track lane */
+      track_remove_empty_last_lanes (
+        region_track);
+
+      region->tmp_lane = NULL;
+    }
+}
+
+/**
+ * Moves the given Region to the given TrackLane.
+ *
+ * Works with TrackLane's of other Track's as well.
+ *
+ * Maintains the selection status of the
+ * Region.
+ *
+ * Assumes that the Region is already in a
+ * TrackLane.
+ *
+ * @param tmp If the Region should be moved
+ *   temporarily (the tmp_lane member will be used
+ *   instead of actually moving).
+ */
+void
+region_move_to_lane (
+  Region *    region,
+  TrackLane * lane,
+  const int   tmp)
+{
+  g_return_if_fail (region && lane);
+
+  Track * region_track =
+    region_get_track (region);
+  g_return_if_fail (region_track);
+
+  if (tmp)
+    {
+      g_warn_if_fail (lane->pos >= 0);
+      set_tmp_lane_to_visible_counterparts (
+        region, NULL, lane);
+    }
+  else
+    {
+      int selected = region_is_selected (region);
+
+      track_remove_region (
+        region_track,
+        region, F_NO_PUBLISH_EVENTS, F_NO_FREE);
+      track_add_region (
+        lane->track, region, NULL,
+        lane->pos,
+        F_NO_GEN_NAME,
+        F_NO_PUBLISH_EVENTS);
+      region_select (
+        region, selected);
+      region_set_lane (region, lane);
+      g_warn_if_fail (
+        lane->pos == region->lane_pos);
+
+      track_create_missing_lanes (
+        region_track, lane->pos);
+      track_remove_empty_last_lanes (region_track);
+    }
+}
+
 /**
  * Sets the automation track.
  */
@@ -345,9 +508,11 @@ region_gen_widget (
 
 #define GEN_W(type,sc) \
   case REGION_TYPE_##type: \
-    r->widget = \
-      Z_REGION_WIDGET ( \
-        sc##_region_widget_new (r)); \
+    if (!r->widget) \
+      r->widget = \
+        Z_REGION_WIDGET ( \
+          sc##_region_widget_new (r)); \
+      g_warn_if_fail (r->widget); \
     break
 
       switch (r->type)
@@ -484,6 +649,22 @@ ARRANGER_OBJ_DECLARE_RESET_COUNTERPART (
     &dest->start_pos, &src->start_pos);
   position_set_to_pos (
     &dest->end_pos, &src->end_pos);
+  dest->tmp_lane = src->tmp_lane;
+
+  src =
+    reset_trans ?
+      region_get_lane_region (region) :
+      region_get_lane_trans_region (region);
+  dest =
+    reset_trans ?
+      region_get_lane_trans_region (region) :
+      region_get_lane_region (region);
+
+  position_set_to_pos (
+    &dest->start_pos, &src->start_pos);
+  position_set_to_pos (
+    &dest->end_pos, &src->end_pos);
+  dest->tmp_lane = src->tmp_lane;
 }
 
 /**
@@ -819,10 +1000,12 @@ region_split (
   /* add them to the track */
   track_add_region (
     region_get_track (region),
-    *r1, region->at, region->lane_pos, 1);
+    *r1, region->at, region->lane_pos,
+    F_GEN_NAME, F_PUBLISH_EVENTS);
   track_add_region (
     region_get_track (region),
-    *r2, region->at, region->lane_pos, 1);
+    *r2, region->at, region->lane_pos,
+    F_GEN_NAME, F_PUBLISH_EVENTS);
 
   /* generate widgets so update visibility in the
    * arranger can work */
@@ -847,7 +1030,7 @@ region_split (
   /* remove and free the original region */
   track_remove_region (
     region_get_track (region),
-    region, F_FREE);
+    region, F_PUBLISH_EVENTS, F_FREE);
 
   EVENTS_PUSH (ET_REGION_CREATED, *r1);
   EVENTS_PUSH (ET_REGION_CREATED, *r2);
@@ -878,7 +1061,8 @@ region_unsplit (
   /* add it to the track */
   track_add_region (
     region_get_track (r1),
-    *region, r1->at, r1->lane_pos, 1);
+    *region, r1->at, r1->lane_pos,
+    F_GEN_NAME, F_PUBLISH_EVENTS);
 
   /* generate widgets so update visibility in the
    * arranger can work */
@@ -900,10 +1084,10 @@ region_unsplit (
   /* remove and free the original regions */
   track_remove_region (
     region_get_track (r1),
-    r1, F_FREE);
+    r1, F_PUBLISH_EVENTS, F_FREE);
   track_remove_region (
     region_get_track (r2),
-    r2, F_FREE);
+    r2, F_PUBLISH_EVENTS, F_FREE);
 
   EVENTS_PUSH (ET_REGION_CREATED, *region);
 }
@@ -1040,13 +1224,13 @@ region_get_num_loops (
 {
   int i = 0;
   long loop_size =
-    region_get_loop_length_in_ticks (region);
+    region_get_loop_length_in_frames (region);
   g_warn_if_fail (loop_size > 0);
   long full_size =
-    region_get_full_length_in_ticks (region);
+    region_get_full_length_in_frames (region);
   long loop_start =
-    position_to_ticks (&region->loop_start_pos) -
-    position_to_ticks (&region->clip_start_pos);
+    position_to_frames (&region->loop_start_pos) -
+    position_to_frames (&region->clip_start_pos);
   long curr_ticks = loop_start;
 
   while (curr_ticks < full_size)
@@ -1135,20 +1319,18 @@ region_clone (
     break;
     case REGION_TYPE_AUDIO:
       {
-        AudioClip * clip =
-          AUDIO_POOL->clips[region->pool_id];
-        g_warn_if_fail (clip && clip->frames);
-
         Region * ar =
           audio_region_new (
+            region->pool_id,
             NULL,
-            clip->frames,
-            clip->num_frames,
-            clip->channels,
+            NULL,
+            -1,
+            0,
             &region->start_pos,
             is_main);
 
         new_region = ar;
+        new_region->pool_id = region->pool_id;
       }
     break;
     case REGION_TYPE_AUTOMATION:
