@@ -38,6 +38,7 @@
 #include "audio/port.h"
 #include "audio/routing.h"
 #include "audio/track.h"
+#include "audio/track_processor.h"
 #include "project.h"
 #include "utils/arrays.h"
 #include "utils/stoat.h"
@@ -149,7 +150,9 @@ get_node_name (
     {
     case ROUTE_NODE_TYPE_PLUGIN:
       return
-        g_strdup (node->pl->descr->name);
+        g_strdup_printf (
+          "%s (Plugin)",
+          node->pl->descr->name);
       break;
     case ROUTE_NODE_TYPE_PORT:
       return
@@ -161,6 +164,11 @@ get_node_name (
           "%s Fader",
           node->fader->channel->track->name);
       break;
+    case ROUTE_NODE_TYPE_TRACK:
+      return
+        g_strdup (
+          node->track->name);
+      break;
     case ROUTE_NODE_TYPE_PREFADER:
       return
         g_strdup_printf (
@@ -226,8 +234,9 @@ node_process (
   GraphNode * node,
   const nframes_t   nframes)
 {
+  /*g_message ("processing %s",*/
+             /*get_node_name (node));*/
   int noroll = 0;
-  Channel * chan;
 
   nframes_t local_offset =
     node->graph->router->local_offset;
@@ -254,8 +263,6 @@ node_process (
       if (!node->terminal)
         return;
     }
-  /*g_message ("processing");*/
-  /*print_node (node);*/
 
   /* global positions in frames (samples) */
   long g_start_frames;
@@ -313,61 +320,22 @@ node_process (
         node->sample_processor, local_offset,
         nframes);
     }
+  else if (node->type ==
+           ROUTE_NODE_TYPE_TRACK)
+    {
+      track_processor_process (
+        &node->track->processor,
+        g_start_frames, local_offset,
+        nframes);
+    }
   else if (node->type == ROUTE_NODE_TYPE_PORT)
     {
-      /* decide what to do based on what port it is */
+      /* decide what to do based on what port it
+       * is */
       Port * port = node->port;
 
-      /* if piano roll */
-      if (port->identifier.flags &
-            PORT_FLAG_PIANO_ROLL)
-        {
-          chan = port->track->channel;
-
-          if (chan->track->type ==
-                TRACK_TYPE_INSTRUMENT ||
-              chan->track->type ==
-                TRACK_TYPE_MIDI)
-            {
-              /* panic MIDI if necessary */
-              if (g_atomic_int_get (
-                    &AUDIO_ENGINE->panic))
-                {
-                  midi_events_panic (
-                    port->midi_events, 1);
-                }
-              /* get events from track if playing */
-              else if (TRANSPORT->play_state ==
-                       PLAYSTATE_ROLLING)
-                {
-                  if (TRANSPORT->recording &&
-                        chan->track->recording)
-                    {
-                      channel_handle_recording (chan);
-                    }
-
-                  /* fill midi events to pass to
-                   * ins plugin */
-                  /*g_message ("filling PR events");*/
-                  midi_track_fill_midi_events (
-                    chan->track,
-                    g_start_frames,
-                    local_offset,
-                    nframes,
-                    port->midi_events);
-                }
-              midi_events_dequeue (
-                port->midi_events);
-              if (port->midi_events->num_events > 0)
-                g_message (
-                  "piano roll port %s has %d events",
-                  port->identifier.label,
-                  port->midi_events->num_events);
-            }
-        }
-
       /* if midi editor manual press */
-      else if (port == AUDIO_ENGINE->
+      if (port == AUDIO_ENGINE->
             midi_editor_manual_press)
         {
           midi_events_dequeue (
@@ -376,53 +344,10 @@ node_process (
                 midi_events);
         }
 
-      /* if channel stereo in */
-      else if (
-          port->identifier.type == TYPE_AUDIO &&
-          port->identifier.flow == FLOW_INPUT &&
-          port->identifier.owner_type ==
-            PORT_OWNER_TYPE_TRACK)
-        {
-          chan = port->track->channel;
-
-          /* fill stereo in buffers with info from
-           * the current clip */
-          int ret;
-          switch (chan->track->type)
-            {
-            case TRACK_TYPE_AUDIO:
-              if (g_atomic_int_get (
-                &chan->filled_stereo_in_bufs))
-                break;
-              ret =
-                g_atomic_int_compare_and_exchange (
-                  &chan->filled_stereo_in_bufs,
-                  0, 1);
-              if (ret)
-                audio_track_fill_stereo_in_buffers (
-                  (AudioTrack *)chan->track,
-                  chan->stereo_in);
-              break;
-            case TRACK_TYPE_MASTER:
-            case TRACK_TYPE_AUDIO_BUS:
-            case TRACK_TYPE_AUDIO_GROUP:
-            case TRACK_TYPE_INSTRUMENT:
-            case TRACK_TYPE_CHORD:
-            case TRACK_TYPE_MARKER:
-            case TRACK_TYPE_MIDI:
-            default:
-              port_sum_signal_from_inputs (
-                port, local_offset,
-                nframes, noroll);
-              break;
-            }
-        }
-
       /* if channel stereo out port */
       else if (port->track &&
           port->identifier.owner_type ==
             PORT_OWNER_TYPE_TRACK &&
-          port->identifier.type == TYPE_AUDIO &&
           port->identifier.flow == FLOW_OUTPUT)
         {
           /* if muted clear it */
@@ -432,8 +357,7 @@ node_process (
                    !port->track->solo &&
                    port->track != P_MASTER_TRACK))
             {
-              /* TODO */
-              /*port_clear_buffer (port);*/
+              port_clear_buffer (port);
             }
           /* if not muted/soloed process it */
           else
@@ -563,6 +487,7 @@ graph_worker_thread (void * g)
           g_warn_if_fail (
             graph->idle_thread_cnt <=
             graph->num_threads);
+          /*g_message ("unlocking");*/
           pthread_mutex_unlock (
             &graph->trigger_mutex);
           /*g_message ("waiting trigger");*/
@@ -581,6 +506,7 @@ graph_worker_thread (void * g)
               graph->trigger_queue[
                 --graph->n_trigger_queue];
         }
+      /*g_message ("unlocking");*/
       pthread_mutex_unlock (&graph->trigger_mutex);
 
       /* process graph-node */
@@ -807,6 +733,22 @@ find_node_from_plugin (
   return NULL;
 }
 
+static GraphNode *
+find_node_from_track (
+  Graph * graph,
+  Track * track)
+{
+  GraphNode * node;
+  for (int i = 0; i < graph->n_graph_nodes; i++)
+    {
+      node = graph->graph_nodes[i];
+      if (node->type == ROUTE_NODE_TYPE_TRACK &&
+          node->track == track)
+        return node;
+    }
+  return NULL;
+}
+
 static GraphNode *
 find_node_from_fader (
   Graph * graph,
@@ -885,20 +827,32 @@ graph_node_new (
   node->id = graph->n_graph_nodes;
   node->graph = graph;
   node->type = type;
-  if (type == ROUTE_NODE_TYPE_PLUGIN)
-    node->pl = (Plugin *) data;
-  else if (type == ROUTE_NODE_TYPE_PORT)
-    node->port = (Port *) data;
-  else if (type == ROUTE_NODE_TYPE_FADER)
-    node->fader = (Fader *) data;
-  else if (type == ROUTE_NODE_TYPE_MONITOR_FADER)
-    node->fader = (Fader *) data;
-  else if (type == ROUTE_NODE_TYPE_PREFADER)
-    node->prefader = (PassthroughProcessor *) data;
-  else if (type ==
-             ROUTE_NODE_TYPE_SAMPLE_PROCESSOR)
-    node->sample_processor =
-      (SampleProcessor *) data;
+  switch (type)
+    {
+    case ROUTE_NODE_TYPE_PLUGIN:
+      node->pl = (Plugin *) data;
+      break;
+    case ROUTE_NODE_TYPE_PORT:
+      node->port = (Port *) data;
+      break;
+    case ROUTE_NODE_TYPE_FADER:
+      node->fader = (Fader *) data;
+      break;
+    case ROUTE_NODE_TYPE_MONITOR_FADER:
+      node->fader = (Fader *) data;
+      break;
+    case ROUTE_NODE_TYPE_PREFADER:
+      node->prefader =
+        (PassthroughProcessor *) data;
+      break;
+    case ROUTE_NODE_TYPE_SAMPLE_PROCESSOR:
+      node->sample_processor =
+        (SampleProcessor *) data;
+      break;
+    case ROUTE_NODE_TYPE_TRACK:
+      node->track = (Track *) data;
+      break;
+    }
 
   return node;
 }
@@ -938,8 +892,9 @@ graph_add_terminal_node (
   node->terminal = 1;
   self->terminal_nodes[
     self->terminal_node_count - 1] = node;
-  /*g_message ("adding terminal node %d",*/
-             /*node->id);*/
+  /*g_message ("adding terminal node %s",*/
+             /*get_node_name (node));*/
+  /*g_warn_if_reached ();*/
   return node;
 }
 
@@ -1014,9 +969,12 @@ graph_terminate (
 	pthread_mutex_unlock (&self->trigger_mutex);
 
 	/* wake-up sleeping threads */
-	for (int i = 0; i < tc; ++i) {
-		zix_sem_post (&self->trigger);
-	}
+	for (int i = 0; i < tc; ++i)
+    {
+      /*g_message ("posting trigger to wake up "*/
+                 /*"sleeping threads");*/
+      zix_sem_post (&self->trigger);
+    }
 	/* and the main thread */
   /*g_message ("locking trigger mutex to post callback");*/
 	pthread_mutex_lock (&self->trigger_mutex);
@@ -1078,7 +1036,7 @@ graph_reached_terminal_node (
       zix_sem_post (&graph->callback_done);
 
       /* now wait for the next cycle to begin */
-      /*g_message ("waiting callback start");*/
+      /*g_message ("waiting for next cycle to begin");*/
       zix_sem_wait (&graph->callback_start);
 
       if (graph->terminate)
@@ -1144,7 +1102,7 @@ router_start_cycle (
     AUDIO_ENGINE->remaining_latency_preroll;
   self->local_offset = local_offset;
   zix_sem_post (&self->graph1->callback_start);
-  /*g_message ("waiting callback done");*/
+  /*g_message ("waiting for cycle to finish");*/
   /*for (int i = 0; i < self->num_threads; i++)*/
   zix_sem_wait (&self->graph1->callback_done);
   /*g_message ("num trigger nodes at end: %d, num init trigger nodes at end %d, num_max trigger nodes at end: %d",*/
@@ -1189,17 +1147,21 @@ add_port (
         graph_add_terminal_node (
           self, ROUTE_NODE_TYPE_PORT, port);
     }
-  else if (port->num_dests == 0 &&
-           port->num_srcs == 0 &&
-           owner != PORT_OWNER_TYPE_PLUGIN &&
-           owner != PORT_OWNER_TYPE_FADER &&
-           owner != PORT_OWNER_TYPE_MONITOR_FADER &&
-           owner != PORT_OWNER_TYPE_PREFADER)
+  else if (
+    port->num_dests == 0 &&
+    port->num_srcs == 0 &&
+    owner != PORT_OWNER_TYPE_PLUGIN &&
+    owner != PORT_OWNER_TYPE_FADER &&
+    owner != PORT_OWNER_TYPE_MONITOR_FADER &&
+    owner != PORT_OWNER_TYPE_PREFADER &&
+    owner != PORT_OWNER_TYPE_TRACK_PROCESSOR)
     {
     }
   else if (port->num_srcs == 0 &&
       !(owner == PORT_OWNER_TYPE_PLUGIN &&
         port->identifier.flow == FLOW_OUTPUT) &&
+      !(owner == PORT_OWNER_TYPE_TRACK_PROCESSOR &&
+        port->identifier.flow == FLOW_OUTPUT) &&
       !(owner == PORT_OWNER_TYPE_FADER &&
         port->identifier.flow == FLOW_OUTPUT) &&
       !(owner == PORT_OWNER_TYPE_MONITOR_FADER &&
@@ -1212,10 +1174,13 @@ add_port (
     graph_add_initial_node (
       self, ROUTE_NODE_TYPE_PORT, port);
   else if (port->num_dests == 0 &&
-           port->num_srcs > 0 &&
+           /*port->num_srcs > 0 &&*/
            !(owner == PORT_OWNER_TYPE_PLUGIN &&
              port->identifier.flow ==
                FLOW_INPUT) &&
+           !(owner == PORT_OWNER_TYPE_TRACK_PROCESSOR &&
+             port->identifier.flow ==
+               FLOW_INPUT) &&
            !(owner == PORT_OWNER_TYPE_FADER &&
              port->identifier.flow ==
                FLOW_INPUT) &&
@@ -1431,6 +1396,11 @@ graph_new (
       if (!tr->channel)
         continue;
 
+      /* add the track */
+      graph_add_node ( \
+        self, ROUTE_NODE_TYPE_TRACK,
+        tr);
+
       /* add the fader */
       graph_add_node ( \
         self, ROUTE_NODE_TYPE_FADER,
@@ -1536,14 +1506,50 @@ graph_new (
     find_node_from_port (self, port);
   node_connect (node, node2);
 
-  Fader * fader;
-  PassthroughProcessor * prefader;
   for (i = 0; i < TRACKLIST->num_tracks; i++)
     {
       tr = TRACKLIST->tracks[i];
       if (!tr->channel)
         continue;
 
+      /* connect the track */
+      node =
+        find_node_from_track (
+          self, tr);
+      g_warn_if_fail (node);
+      if (tr->in_signal_type == TYPE_AUDIO)
+        {
+          port = tr->processor.stereo_in->l;
+          node2 =
+            find_node_from_port (self, port);
+          node_connect (node2, node);
+          port = tr->processor.stereo_in->r;
+          node2 =
+            find_node_from_port (self, port);
+          node_connect (node2, node);
+          port = tr->processor.stereo_out->l;
+          node2 =
+            find_node_from_port (self, port);
+          node_connect (node, node2);
+          port = tr->processor.stereo_out->r;
+          node2 =
+            find_node_from_port (self, port);
+          node_connect (node, node2);
+        }
+      else if (tr->in_signal_type == TYPE_EVENT)
+        {
+          port = tr->processor.midi_in;
+          node2 =
+            find_node_from_port (self, port);
+          node_connect (node2, node);
+          port = tr->processor.midi_out;
+          node2 =
+            find_node_from_port (self, port);
+          node_connect (node, node2);
+        }
+
+      Fader * fader;
+      PassthroughProcessor * prefader;
       fader = &tr->channel->fader;
       prefader = &tr->channel->prefader;
 
@@ -1551,6 +1557,7 @@ graph_new (
       node =
         find_node_from_fader (
           self, fader);
+      g_warn_if_fail (node);
       if (fader->type == FADER_TYPE_AUDIO_CHANNEL)
         {
           port = fader->stereo_in->l;
@@ -1587,6 +1594,7 @@ graph_new (
       node =
         find_node_from_prefader (
           self, prefader);
+      g_warn_if_fail (node);
       if (prefader->type ==
             PP_TYPE_AUDIO_CHANNEL)
         {
@@ -1626,6 +1634,7 @@ graph_new (
  \
           node = \
             find_node_from_plugin (self, pl); \
+          g_warn_if_fail (node); \
           for (k = 0; k < pl->num_in_ports; k++) \
             { \
               port = pl->in_ports[k]; \
