@@ -342,49 +342,6 @@ track_select (
         self);
     }
 
-  /* auto-set recording mode */
-  Channel * ch = self->channel;
-  switch (self->type)
-    {
-    case TRACK_TYPE_INSTRUMENT:
-    case TRACK_TYPE_AUDIO:
-    case TRACK_TYPE_MIDI:
-      g_warn_if_fail (ch);
-      g_message (
-        "%sselecting track %s, recording %d sa %d",
-        select ? "" : "de",
-        self->name,
-        self->recording,
-        ch->record_set_automatically);
-      /* if selecting the track and recording is not already
-       * on, turn these on */
-      if (select && !self->recording)
-        {
-          track_set_recording (self, 1);
-          ch->record_set_automatically = 1;
-        }
-      /* if deselecting and record mode was
-       * automatically
-       * set when the track was selected, turn
-       * these off */
-      else if (!select &&
-               ch->record_set_automatically)
-        {
-          track_set_recording (self, 0);
-          ch->record_set_automatically = 0;
-        }
-      break;
-    case TRACK_TYPE_CHORD:
-    case TRACK_TYPE_MASTER:
-    case TRACK_TYPE_AUDIO_BUS:
-    case TRACK_TYPE_AUDIO_GROUP:
-    case TRACK_TYPE_MIDI_BUS:
-    case TRACK_TYPE_MIDI_GROUP:
-      break;
-    default:
-      break;
-    }
-
   if (fire_events)
     {
       EVENTS_PUSH (ET_TRACK_CHANGED,
@@ -393,11 +350,13 @@ track_select (
 }
 
 /**
- * Sets recording and connects/disconnects the JACK ports.
+ * Sets recording and connects/disconnects the
+ * JACK ports.
  */
 void
-track_set_recording (Track *   track,
-                     int       recording)
+track_set_recording (
+  Track *   track,
+  int       recording)
 {
   Channel * channel =
     track_get_channel (track);
@@ -450,18 +409,20 @@ track_set_recording (Track *   track,
  * to the undo stack.
  */
 void
-track_set_muted (Track * track,
-                 int     mute,
-                 int     trigger_undo)
+track_set_muted (
+  Track * track,
+  int     mute,
+  int     trigger_undo)
 {
+  TracklistSelections tls;
+  tls.tracks[0] = track;
+  tls.num_tracks = 1;
   UndoableAction * action =
     edit_tracks_action_new (
       EDIT_TRACK_ACTION_TYPE_MUTE,
       track,
-      TRACKLIST_SELECTIONS,
+      &tls,
       0.f, 0.f, 0, mute);
-  g_message ("setting mute to %d",
-             mute);
   if (trigger_undo)
     {
       undo_manager_perform (UNDO_MANAGER,
@@ -547,15 +508,19 @@ track_get_velocities_in_range (
  * adds the action to the undo stack.
  */
 void
-track_set_soloed (Track * track,
-                  int     solo,
-                  int     trigger_undo)
+track_set_soloed (
+  Track * track,
+  int     solo,
+  int     trigger_undo)
 {
+  TracklistSelections tls;
+  tls.tracks[0] = track;
+  tls.num_tracks = 1;
   UndoableAction * action =
     edit_tracks_action_new (
       EDIT_TRACK_ACTION_TYPE_SOLO,
       track,
-      TRACKLIST_SELECTIONS,
+      &tls,
       0.f, 0.f, solo, 0);
   if (trigger_undo)
     {
@@ -708,8 +673,10 @@ track_add_region (
   Region * region,
   AutomationTrack * at,
   int      lane_pos,
-  int      gen_name)
+  int      gen_name,
+  int      fire_events)
 {
+  g_message ("adding region to lane %d", lane_pos);
   g_warn_if_fail (
     region->obj_info.counterpart ==
     AOI_COUNTERPART_MAIN);
@@ -762,16 +729,13 @@ track_add_region (
 
   if (add_lane)
     {
+      /* enable extra lane if necessary */
+      track_create_missing_lanes (track, lane_pos);
+
       g_warn_if_fail (track->lanes[lane_pos]);
       track_lane_add_region (
         track->lanes[lane_pos],
         region);
-
-      /* enable extra lane if necessary */
-      if (lane_pos == track->num_lanes - 1)
-        {
-          track_add_lane (track);
-        }
     }
 
   if (add_at)
@@ -792,8 +756,62 @@ track_add_region (
                     region);
     }
 
-  EVENTS_PUSH (ET_REGION_CREATED,
-               region);
+  if (fire_events)
+    {
+      EVENTS_PUSH (ET_REGION_CREATED,
+                   region);
+    }
+}
+
+/**
+ * Creates missing TrackLane's until pos.
+ */
+void
+track_create_missing_lanes (
+  Track *   track,
+  const int pos)
+{
+  while (track->num_lanes < pos + 2)
+    {
+      g_message ("adding missing lane");
+      track_add_lane (track);
+    }
+}
+
+/**
+ * Removes the empty last lanes of the Track
+ * (except the last one).
+ */
+void
+track_remove_empty_last_lanes (
+  Track * track)
+{
+  g_return_if_fail (track);
+  g_message ("removing empty last lanes from %s",
+             track->name);
+  int removed = 0;
+  for (int i = track->num_lanes - 1; i >= 1; i--)
+    {
+      g_message ("lane %d has %d regions",
+                 i, track->lanes[i]->num_regions);
+      if (track->lanes[i]->num_regions > 0)
+        break;
+
+      if (track->lanes[i]->num_regions == 0 &&
+          track->lanes[i - 1]->num_regions == 0)
+        {
+          g_message ("removing lane %d", i);
+          track->num_lanes--;
+          free_later (
+            track->lanes[i], track_lane_free);
+          removed = 1;
+        }
+    }
+
+  if (removed)
+    {
+      EVENTS_PUSH (ET_TRACK_LANE_REMOVED, NULL);
+    }
 }
 
 /**
@@ -850,14 +868,18 @@ track_set_pos (
  */
 void
 track_remove_region (
-  Track * track,
+  Track *  track,
   Region * region,
-  int     free)
+  int      fire_events,
+  int      free)
 {
   region_disconnect (region);
 
   g_warn_if_fail (region->lane_pos >= 0);
 
+  g_message (
+    "removed region from lane %d (track %s)",
+    region->lane_pos, track->name);
   array_delete (
     track->lanes[region->lane_pos]->regions,
     track->lanes[region->lane_pos]->num_regions,
@@ -866,7 +888,10 @@ track_remove_region (
   if (free)
     free_later (region, region_free_all);
 
-  EVENTS_PUSH (ET_REGION_REMOVED, track);
+  if (fire_events)
+    {
+      EVENTS_PUSH (ET_REGION_REMOVED, track);
+    }
 }
 
 /**
@@ -1023,7 +1048,7 @@ track_get_channel (Track * track)
     case TRACK_TYPE_MIDI:
       return track->channel;
     default:
-      g_return_val_if_reached (NULL);
+      return NULL;
     }
 }
 
@@ -1038,7 +1063,8 @@ track_get_region_at_pos (
   int i, j;
 
   if (track->type == TRACK_TYPE_INSTRUMENT ||
-      track->type == TRACK_TYPE_AUDIO)
+      track->type == TRACK_TYPE_AUDIO ||
+      track->type == TRACK_TYPE_MIDI)
     {
       TrackLane * lane;
       Region * r;
@@ -1049,10 +1075,10 @@ track_get_region_at_pos (
           for (j = 0; j < lane->num_regions; j++)
             {
               r = lane->regions[j];
-              if (position_is_after_or_equal (
-                    pos, &r->start_pos) &&
-                  position_is_before_or_equal (
-                    pos, &r->end_pos))
+              if (pos->frames >=
+                    r->start_pos.frames &&
+                  pos->frames <=
+                    r->end_pos.frames)
                 return r;
             }
         }
