@@ -284,7 +284,6 @@ on_clip_editor_region_changed ()
   /* TODO */
   /*gtk_notebook_set_current_page (MAIN_WINDOW->bot_notebook, 0);*/
   Region * r = CLIP_EDITOR->region;
-  g_warn_if_fail (r);
 
   if (r)
     {
@@ -1016,6 +1015,7 @@ events_process (void * data)
               /*GTK_WIDGET (MW_PINNED_TRACKLIST)));*/
           break;
         case ET_TRACK_LANE_ADDED:
+        case ET_TRACK_LANE_REMOVED:
           tracklist_widget_soft_refresh (
             MW_TRACKLIST);
           timeline_arranger_widget_update_visibility (
@@ -1042,10 +1042,10 @@ events_process (void * data)
             GTK_WIDGET (EDITOR_RULER));
           break;
         case ET_TIMELINE_OBJECTS_IN_TRANSIT:
-          timeline_arranger_widget_refresh_children (
-            MW_TIMELINE);
-          timeline_arranger_widget_refresh_children (
-            MW_PINNED_TIMELINE);
+          /*timeline_arranger_widget_refresh_children (*/
+            /*MW_TIMELINE);*/
+          /*timeline_arranger_widget_refresh_children (*/
+            /*MW_PINNED_TIMELINE);*/
           if (TL_SELECTIONS->num_regions > 0)
             editor_ruler_widget_refresh (
               EDITOR_RULER);
