@@ -112,6 +112,15 @@ tracklist_selections_add_track (
       EVENTS_PUSH (ET_TRACKLIST_SELECTIONS_CHANGED,
                    NULL);
     }
+
+  /* if recording is not already
+   * on, turn these on */
+  if (!track->recording && track->channel)
+    {
+      track_set_recording (track, 1);
+      track->channel->record_set_automatically =
+        1;
+    }
 }
 
 /**
@@ -156,6 +165,16 @@ tracklist_selections_remove_track (
       return;
     }
 
+    /* if record mode was set automatically
+     * when the track was selected, turn record
+     * off */
+  if (track->channel &&
+      track->channel->record_set_automatically)
+    {
+      track_set_recording (track, 0);
+      track->channel->record_set_automatically = 0;
+    }
+
   array_delete (
     ts->tracks,
     ts->num_tracks,
@@ -283,13 +302,11 @@ tracklist_selections_toggle_visibility (
  */
 TracklistSelections *
 tracklist_selections_clone (
-  TracklistSelections * self)
+  TracklistSelections * src)
 {
   TracklistSelections * new_ts =
     calloc (1, sizeof (TracklistSelections));
 
-  TracklistSelections * src = TRACKLIST_SELECTIONS;
-
   for (int i = 0; i < src->num_tracks; i++)
     {
       Track * r = src->tracks[i];
