@@ -99,7 +99,7 @@ channel_widget_update_meter_reading (
   double val =
     (channel_get_current_l_db (channel) +
       channel_get_current_r_db (channel)) / 2;
-  if (val == prev)
+  if (math_doubles_equal (val, prev, 0.001))
     return G_SOURCE_CONTINUE;
   char * string;
   if (val < -100.)
@@ -212,8 +212,8 @@ on_drag_data_get (
     gdk_atom_intern_static_string (
       TARGET_ENTRY_TRACK),
     32,
-    (const guchar *) P_MASTER_TRACK,
-    sizeof (Track));
+    (const guchar *) &P_MASTER_TRACK,
+    sizeof (P_MASTER_TRACK));
 }
 
 /**
@@ -379,7 +379,9 @@ on_whole_channel_press (
 {
   self->n_press = n_press;
 
-  UI_GET_STATE_MASK (gesture);
+  GdkModifierType state_mask =
+    ui_get_state_mask (
+      GTK_GESTURE (gesture));
   self->ctrl_held_at_start =
     state_mask & GDK_CONTROL_MASK;
 }
@@ -519,8 +521,9 @@ setup_phase_panel (ChannelWidget * self)
                        0, 1, 0);
   gtk_label_set_text (
     self->phase_reading,
-    g_strdup_printf ("%.1f",
-                     self->channel->fader.phase));
+    g_strdup_printf (
+      "%.1f",
+      (double) self->channel->fader.phase));
 }
 
 static void
@@ -615,7 +618,7 @@ static void
 refresh_output (ChannelWidget * self)
 {
   route_target_selector_widget_refresh (
-    self->output);
+    self->output, self->channel);
 }
 
 static void
@@ -764,7 +767,7 @@ channel_widget_new (Channel * channel)
     self->name, self->channel->track,
     track_get_name, track_set_name);
   route_target_selector_widget_setup (
-    self->output, self);
+    self->output, self->channel);
   channel_widget_refresh (self);
 
   gtk_widget_add_tick_callback (
@@ -906,6 +909,8 @@ channel_widget_init (ChannelWidget * self)
     context, "channel_label");
   gtk_label_set_max_width_chars (
     self->name->label, 10);
+  gtk_label_set_max_width_chars (
+    self->output->label, 9);
 
   /* setup inserts */
   GtkWidget * inserts_scroll =
@@ -941,7 +946,9 @@ channel_widget_init (ChannelWidget * self)
     self->inserts_expander, _("Inserts"));
 
   GtkTargetEntry entries[1];
-  entries[0].target = TARGET_ENTRY_TRACK;
+  /* FIXME free */
+  entries[0].target =
+    g_strdup (TARGET_ENTRY_TRACK);
   entries[0].flags = GTK_TARGET_SAME_APP;
   entries[0].info =
     symap_map (ZSYMAP, TARGET_ENTRY_TRACK);
