@@ -226,14 +226,18 @@ region_widget_draw_name (
 {
   REGION_WIDGET_GET_PRIVATE (self);
 
+  Region * region = rw_prv->region;
+  g_return_if_fail (
+    region &&
+    region->name);
+
   int width =
     gtk_widget_get_allocated_width (
       GTK_WIDGET (self));
 
   char * str =
-    g_strdup (rw_prv->region->name);
+    g_strdup (region->name);
   char * new_str = str;
-  Region * region = rw_prv->region;
   if (DEBUGGING)
     {
       if (region_is_transient (region))
@@ -445,6 +449,11 @@ region_widget_is_resize_l (
   RegionWidget * self,
   int             x)
 {
+  /* FIXME temporary */
+  REGION_WIDGET_GET_PRIVATE (self);
+  if (rw_prv->region->type == REGION_TYPE_AUDIO)
+    return 0;
+
   if (x < RESIZE_CURSOR_SPACE)
     {
       return 1;
@@ -485,6 +494,10 @@ region_widget_is_resize_loop (
   REGION_WIDGET_GET_PRIVATE (self);
 
   Region * r = rw_prv->region;
+
+  if (r->type == REGION_TYPE_AUDIO)
+    return 1;
+
   if ((position_to_ticks (&r->end_pos) -
        position_to_ticks (&r->start_pos)) >
       position_to_ticks (&r->loop_end_pos))
