@@ -102,6 +102,7 @@ timeline_arranger_widget_set_allocation (
   GtkWidget *          widget,
   GdkRectangle *       allocation)
 {
+  ARRANGER_WIDGET_GET_PRIVATE (self);
   if (Z_IS_REGION_WIDGET (widget))
     {
       RegionWidget * rw = Z_REGION_WIDGET (widget);
@@ -110,6 +111,18 @@ timeline_arranger_widget_set_allocation (
       TrackLane * lane = region->lane;
       Track * track = region_get_track (region);
 
+      /* if region has a tmp_lane then it means
+       * that we are in an operation we should
+       * display it there instead of its original
+       * lane */
+      if (ar_prv->action !=
+            UI_OVERLAY_ACTION_NONE &&
+          region->tmp_lane)
+        {
+          lane = region->tmp_lane;
+          track = lane->track;
+        }
+
       if (!track->widget)
         track->widget = track_widget_new (track);
 
@@ -121,6 +134,8 @@ timeline_arranger_widget_set_allocation (
         (ui_pos_to_px_timeline (
           &rw_prv->region->end_pos,
           1) - allocation->x) - 1;
+      if (allocation->width < 1)
+        allocation->width = 1;
 
       TRACK_WIDGET_GET_PRIVATE (track->widget);
 
@@ -129,7 +144,8 @@ timeline_arranger_widget_set_allocation (
         &rw_prv->region->obj_info;
       if (arranger_object_info_is_lane (nfo))
         {
-          if (!track->lanes_visible)
+          if (!track->lanes_visible ||
+              !GTK_IS_WIDGET (lane->widget))
             return;
 
           gtk_widget_translate_coordinates(
@@ -520,10 +536,12 @@ timeline_arranger_widget_get_track_at_y (
       if (!track->visible)
         continue;
 
+      g_warn_if_fail (track->widget);
+
       if (ui_is_child_hit (
             GTK_WIDGET (self),
             GTK_WIDGET (track->widget),
-            0, 1, 0, y, 0, 0))
+            0, 1, 0, y, 0, 1))
         return track;
     }
 
@@ -1094,19 +1112,20 @@ timeline_arranger_widget_create_region (
         track, region, NULL,
         lane ? lane->pos :
         (track->num_lanes == 1 ?
-         0 : track->num_lanes - 2), F_GEN_NAME);
+         0 : track->num_lanes - 2), F_GEN_NAME,
+        F_PUBLISH_EVENTS);
       break;
     case REGION_TYPE_AUDIO:
       break;
     case REGION_TYPE_CHORD:
       track_add_region (
         track, region, NULL,
-        -1, F_GEN_NAME);
+        -1, F_GEN_NAME, F_PUBLISH_EVENTS);
       break;
     case REGION_TYPE_AUTOMATION:
       track_add_region (
         track, region, at,
-        -1, F_GEN_NAME);
+        -1, F_GEN_NAME, F_PUBLISH_EVENTS);
       break;
     }
 
@@ -1347,7 +1366,7 @@ timeline_arranger_widget_select (
           /* delete the enclosed region */
           track_remove_region (
             region->lane->track, region,
-            F_FREE);
+            F_PUBLISH_EVENTS, F_FREE);
         }
       else
         {
@@ -1827,6 +1846,173 @@ timeline_arranger_widget_setup (
     NULL);
 }
 
+/**
+ * Move the selected Regions to new Lanes.
+ *
+ * @param diff The delta to move the
+ *   Tracks.
+ *
+ * @return 1 if moved.
+ */
+static int
+move_regions_to_new_lanes (
+  TimelineArrangerWidget * self,
+  const int                diff)
+{
+  int i;
+
+  /* store selected regions because they will be
+   * deselected during moving */
+  Region * regions[600];
+  int num_regions = 0;
+  Region * region;
+  for (i = 0; i < TL_SELECTIONS->num_regions; i++)
+    {
+      regions[num_regions++] =
+        TL_SELECTIONS->regions[i];
+    }
+
+  /* check that:
+   * - all regions are in the same track
+   * - only lane regions are selected
+   * - the lane bounds are not exceeded */
+  int compatible = 1;
+  for (i = 0; i < num_regions; i++)
+    {
+      region = regions[i];
+      region =
+        region_get_lane_region (region);
+      TrackLane * lane = region->lane;
+      if (region->tmp_lane)
+        lane = region->tmp_lane;
+      if (lane->pos + diff < 0)
+        {
+          compatible = 0;
+          break;
+        }
+    }
+  if (TL_SELECTIONS->num_scale_objects > 0 ||
+      TL_SELECTIONS->num_markers > 0)
+    compatible = 0;
+  if (!compatible)
+    return 0;
+
+  /* new positions are all compatible, move the
+   * regions */
+  for (i = 0; i < num_regions; i++)
+    {
+      region = regions[i];
+      region =
+        region_get_lane_region (region);
+      TrackLane * lane = region->lane;
+      if (region->tmp_lane)
+        lane = region->tmp_lane;
+      g_return_val_if_fail (region && lane, -1);
+
+      TrackLane * lane_to_move_to = NULL;
+      int new_lane_pos =
+        lane->pos +  diff;
+      g_return_val_if_fail (
+        new_lane_pos >= 0, -1);
+      track_create_missing_lanes (
+        lane->track, new_lane_pos);
+      lane_to_move_to =
+        lane->track->lanes[new_lane_pos];
+      g_warn_if_fail (lane_to_move_to);
+
+      region_move_to_lane (
+        region, lane_to_move_to, 1);
+    }
+  return 1;
+}
+
+/**
+ * Move the selected Regions to the new Track.
+ *
+ * @param new_track_is_before 1 if the Region's
+ *   should move to their previous tracks, 0 for
+ *   their next tracks.
+ *
+ * @return 1 if moved.
+ */
+static int
+move_regions_to_new_tracks (
+  TimelineArrangerWidget * self,
+  const int                vis_track_diff)
+{
+  int i;
+
+  /* store selected regions because they will be
+   * deselected during moving */
+  Region * regions[600];
+  int num_regions = 0;
+  Region * region;
+  for (i = 0; i < TL_SELECTIONS->num_regions; i++)
+    {
+      regions[num_regions++] =
+        TL_SELECTIONS->regions[i];
+    }
+
+  /* check that all regions can be moved to a
+   * compatible track */
+  int compatible = 1;
+  for (i = 0; i < num_regions; i++)
+    {
+      region = regions[i];
+      region =
+        (Region *)
+        arranger_object_info_get_visible_counterpart (
+          &region->obj_info);
+      Track * region_track =
+        region_get_track (region);
+      if (region->tmp_lane)
+        region_track = region->tmp_lane->track;
+      Track * visible =
+        tracklist_get_visible_track_after_delta (
+          TRACKLIST,
+          region_track,
+          vis_track_diff);
+      if (
+        !visible ||
+        !track_type_is_compatible_for_moving (
+           region_track->type,
+           visible->type))
+        {
+          compatible = 0;
+          break;
+        }
+    }
+  if (!compatible)
+    return 0;
+
+  /* new positions are all compatible, move the
+   * regions */
+  for (i = 0; i < num_regions; i++)
+    {
+      region = regions[i];
+      region =
+        (Region *)
+        arranger_object_info_get_visible_counterpart (
+          &region->obj_info);
+      Track * region_track =
+        region_get_track (region);
+      if (region->tmp_lane)
+        region_track = region->tmp_lane->track;
+      g_warn_if_fail (region && region_track);
+      Track * track_to_move_to =
+        tracklist_get_visible_track_after_delta (
+          TRACKLIST,
+          region_track,
+          vis_track_diff);
+      g_warn_if_fail (track_to_move_to);
+
+      region_move_to_track (
+        region, track_to_move_to, 1);
+    }
+
+  return 1;
+}
+
 void
 timeline_arranger_widget_move_items_y (
   TimelineArrangerWidget * self,
@@ -1834,118 +2020,74 @@ timeline_arranger_widget_move_items_y (
 {
   ARRANGER_WIDGET_GET_PRIVATE (self);
 
-  if (TL_SELECTIONS->num_regions)
+  /* get old track, track where last change
+   * happened, and new track */
+  Track * track =
+    timeline_arranger_widget_get_track_at_y (
+    self, ar_prv->start_y + offset_y);
+  Track * old_track =
+    timeline_arranger_widget_get_track_at_y (
+    self, ar_prv->start_y);
+  Track * last_track =
+    tracklist_get_visible_track_after_delta (
+      TRACKLIST, old_track,
+      self->visible_track_diff);
+
+  /* TODO automations and other lanes */
+  TrackLane * lane =
+    timeline_arranger_widget_get_track_lane_at_y (
+    self, ar_prv->start_y + offset_y);
+  TrackLane * old_lane =
+    timeline_arranger_widget_get_track_lane_at_y (
+    self, ar_prv->start_y);
+  TrackLane * last_lane = NULL;
+  if (old_lane)
+    last_lane =
+      old_lane->track->lanes[
+        old_lane->pos + self->lane_diff];
+
+  /* if new track is equal, move lanes or
+   * automation lanes */
+  if (track && last_track &&
+      track == last_track &&
+      self->visible_track_diff == 0 &&
+      old_lane && lane && last_lane)
     {
-      /* check if should be moved to new track */
-      Track * track =
-        timeline_arranger_widget_get_track_at_y (
-        self, ar_prv->start_y + offset_y);
-      Track * old_track =
-        region_get_track (self->start_region);
-      if (track)
+      int cur_diff =
+        lane->pos - old_lane->pos;
+      int delta =
+        lane->pos - last_lane->pos;
+      if (delta != 0)
         {
-          Track * pt =
-            tracklist_get_prev_visible_track (
-              TRACKLIST, old_track);
-          Track * nt =
-            tracklist_get_next_visible_track (
-              TRACKLIST, old_track);
-          Track * tt =
-            tracklist_get_first_visible_track (
-              TRACKLIST);
-          Track * bt =
-            tracklist_get_last_visible_track (
-              TRACKLIST);
-          /* highest selected track */
-          Track * hst =
-            timeline_selections_get_highest_track (
-              TL_SELECTIONS,
-              arranger_widget_is_in_moving_operation (
-                Z_ARRANGER_WIDGET (self)));
-          /* lowest selected track */
-          Track * lst =
-            timeline_selections_get_lowest_track (
-              TL_SELECTIONS,
-              arranger_widget_is_in_moving_operation (
-                Z_ARRANGER_WIDGET (self)));
-
-          if (region_get_track (self->start_region)
-                != track)
+          int moved =
+            move_regions_to_new_lanes (
+              self, delta);
+          if (moved)
             {
-              /* if new track is lower and bot region is not at the lowest track */
-              if (track == nt &&
-                  lst != bt)
-                {
-                  /* shift all selected regions to their next track */
-                  for (int i = 0; i < TL_SELECTIONS->num_regions; i++)
-                    {
-                      Region * region =
-                        TL_SELECTIONS->regions[i];
-                      region = region_get_main_trans_region (region);
-                      nt =
-                        tracklist_get_next_visible_track (
-                          TRACKLIST,
-                          region->lane->track);
-                      old_track = region->lane->track;
-                      if (old_track->type == nt->type)
-                        {
-                          if (nt->type ==
-                                TRACK_TYPE_INSTRUMENT)
-                            {
-                              track_remove_region (
-                                old_track,
-                                region, F_NO_FREE);
-                              track_add_region (
-                                nt, region, NULL,
-                                0, F_NO_GEN_NAME);
-                            }
-                          else if (nt->type ==
-                                     TRACK_TYPE_AUDIO)
-                            {
-                              /* TODO */
-
-                            }
-                        }
-                    }
-                }
-              else if (track == pt &&
-                       hst != tt)
-                {
-                  /*g_message ("track %s top region track %s tt %s",*/
-                             /*track->channel->name,*/
-                             /*self->top_region->track->channel->name,*/
-                             /*tt->channel->name);*/
-                  /* shift all selected regions to their prev track */
-                  for (int i = 0; i < TL_SELECTIONS->num_regions; i++)
-                    {
-                      Region * region = TL_SELECTIONS->regions[i];
-                      pt =
-                        tracklist_get_prev_visible_track (
-                          TRACKLIST,
-                          region->lane->track);
-                      old_track = region->lane->track;
-                      if (old_track->type == pt->type)
-                        {
-                          if (pt->type ==
-                                TRACK_TYPE_INSTRUMENT)
-                            {
-                              track_remove_region (
-                                old_track,
-                                region, F_NO_FREE);
-                              track_add_region (
-                                pt, region, 0,
-                                F_NO_GEN_NAME,
-                                F_NO_GEN_WIDGET);
-                            }
-                          else if (pt->type ==
-                                     TRACK_TYPE_AUDIO)
-                            {
-                              /* TODO */
-
-                            }
-                        }
-                    }
-                }
+              self->lane_diff =
+                cur_diff;
+            }
+        }
+    }
+  /* otherwise move tracks */
+  else if (track && last_track && old_track &&
+           track != last_track)
+    {
+      int cur_diff =
+        tracklist_get_visible_track_diff (
+          TRACKLIST, old_track, track);
+      int delta =
+        tracklist_get_visible_track_diff (
+          TRACKLIST, last_track, track);
+      if (delta != 0)
+        {
+          int moved =
+            move_regions_to_new_tracks (
+              self, delta);
+          if (moved)
+            {
+              self->visible_track_diff =
+                cur_diff;
             }
         }
     }
@@ -1961,6 +2103,16 @@ timeline_arranger_widget_on_drag_end (
 {
   ARRANGER_WIDGET_GET_PRIVATE (self);
 
+  /* clear tmp_lane from selected regions */
+  for (int i = 0; i < TL_SELECTIONS->num_regions;
+       i++)
+    {
+      Region * region = TL_SELECTIONS->regions[i];
+      ARRANGER_OBJ_SET_PRIMITIVE_VAL (
+        Region, region, tmp_lane,
+        NULL, AO_UPDATE_ALL);
+    }
+
   switch (ar_prv->action)
     {
     case UI_OVERLAY_ACTION_RESIZING_L:
@@ -2086,16 +2238,13 @@ timeline_arranger_widget_on_drag_end (
         long ticks_diff =
           earliest_main_pos.total_ticks -
             earliest_trans_pos.total_ticks;
-        int tracks_diff =
-          timeline_selections_get_highest_track (
-            TL_SELECTIONS, F_NO_TRANSIENTS)->pos -
-          timeline_selections_get_highest_track (
-            TL_SELECTIONS, F_TRANSIENTS)->pos;
         UndoableAction * ua =
           (UndoableAction *)
           move_timeline_selections_action_new (
             TL_SELECTIONS,
-            ticks_diff, tracks_diff);
+            ticks_diff,
+            self->visible_track_diff,
+            self->lane_diff);
         undo_manager_perform (
           UNDO_MANAGER, ua);
         timeline_selections_reset_counterparts (
@@ -2116,18 +2265,15 @@ timeline_arranger_widget_on_drag_end (
         long ticks_diff =
           earliest_main_pos.total_ticks -
             earliest_trans_pos.total_ticks;
-        int tracks_diff =
-          timeline_selections_get_highest_track (
-            TL_SELECTIONS, F_NO_TRANSIENTS)->pos -
-          timeline_selections_get_highest_track (
-            TL_SELECTIONS, F_TRANSIENTS)->pos;
         timeline_selections_reset_counterparts (
           TL_SELECTIONS, 0);
         UndoableAction * ua =
           (UndoableAction *)
           duplicate_timeline_selections_action_new (
             TL_SELECTIONS,
-            ticks_diff, tracks_diff);
+            ticks_diff,
+            self->visible_track_diff,
+            self->lane_diff);
         timeline_selections_reset_counterparts (
           TL_SELECTIONS, 1);
         timeline_selections_clear (
@@ -2186,12 +2332,12 @@ timeline_arranger_widget_on_drag_end (
   timeline_arranger_widget_update_visibility (
     self);
 
-  timeline_arranger_widget_refresh_children (self);
-
   self->resizing_range = 0;
   self->resizing_range_start = 0;
   self->start_region = NULL;
   self->start_region_was_selected = 0;
+  self->visible_track_diff = 0;
+  self->lane_diff = 0;
 
   EVENTS_PUSH (ET_TL_SELECTIONS_CHANGED,
                NULL);
@@ -2339,17 +2485,16 @@ add_children_from_midi_track (
               if (k == 0)
                 r = region_get_main_region (r);
               else if (k == 1)
-                r = region_get_main_trans_region (r);
+                r =
+                  region_get_main_trans_region (r);
               else if (k == 2)
                 r = region_get_lane_region (r);
               else if (k == 3)
-                r = region_get_lane_trans_region (r);
+                r =
+                  region_get_lane_trans_region (r);
 
-              if (!r->widget)
-                r->widget =
-                  Z_REGION_WIDGET (
-                    midi_region_widget_new (
-                      r));
+              if (!GTK_IS_WIDGET (r->widget))
+                region_gen_widget (r);
 
               gtk_overlay_add_overlay (
                 GTK_OVERLAY (self),
