@@ -2107,7 +2107,7 @@ lv2_plugin_process (
    * something has changed */
   const bool xport_changed =
     lv2_plugin->rolling !=
-      (IS_TRANSPORT_ROLLING) ||
+      (TRANSPORT_IS_ROLLING) ||
     /* FIXME don't save Position in Lv2Plugin.
      * only safe long frames. */
     lv2_plugin->gframes !=
@@ -2184,7 +2184,7 @@ lv2_plugin_process (
 
   /* Update transport state to expected values for
    * next cycle */
-  if (IS_TRANSPORT_ROLLING)
+  if (TRANSPORT_IS_ROLLING)
     {
       lv2_plugin->gframes =
         transport_frames_add_frames (
@@ -2264,12 +2264,14 @@ lv2_plugin_process (
                 {
                   MidiEvent * ev =
                     &port->midi_events->events[i];
-                  g_message ("plugin event %d", i);
-                  g_message ("buf time %u %hhx %hhx %hhx",
-                             ev->time,
-                             ev->raw_buffer[0],
-                             ev->raw_buffer[1],
-                             ev->raw_buffer[2]);
+                  g_message (
+                    "writing plugin event %d:\n"
+                    "buf time %u %hhx %hhx %hhx",
+                    i,
+                    ev->time,
+                    ev->raw_buffer[0],
+                    ev->raw_buffer[1],
+                    ev->raw_buffer[2]);
                   lv2_evbuf_write (
                     &iter,
                     ev->time, 0,
