@@ -76,7 +76,7 @@ tear_down (Project * self)
   if (self->title)
     g_free (self->title);
 
-  engine_tear_down ();
+  engine_tear_down (AUDIO_ENGINE);
 
   track_free (P_CHORD_TRACK);
 
@@ -117,7 +117,7 @@ get_newer_backup (
   Project * self)
 {
   GDir *dir;
-  GError *error;
+  GError *error = NULL;
   const gchar *filename;
   struct stat stat_res;
   struct tm *orig_tm, *nowtm;
@@ -144,6 +144,10 @@ get_newer_backup (
   char * backups_dir =
     project_get_backups_dir (self);
   dir = g_dir_open (backups_dir, 0, &error);
+  if (!dir)
+    {
+      return NULL;
+    }
   while ((filename = g_dir_read_name(dir)))
     {
       char * full_path =
@@ -176,11 +180,13 @@ get_newer_backup (
           g_warning (
             "Failed to get last modified for %s",
             full_path);
+          g_dir_close (dir);
           return NULL;
         }
       g_free (full_path);
     }
   g_free (backups_dir);
+  g_dir_close (dir);
 
   return result;
 }
@@ -274,7 +280,7 @@ project_sanity_check (Project * self)
   /* TODO */
 }
 
-void
+static void
 create_default (Project * self)
 {
   engine_init (&self->audio_engine, 0);
@@ -437,6 +443,8 @@ load (
   g_free (project_file_path);
 
   Project * prj = project_deserialize (yaml);
+  prj->backup_dir =
+    g_strdup (PROJECT->backup_dir);
 
   char * version = zrythm_get_version (0);
   if (!string_is_equal (
@@ -480,10 +488,8 @@ load (
       PROJECT = prj;
 
       MainWindowWidget * mww = MAIN_WINDOW;
-
-      g_message ("recreating main window...");
-      MAIN_WINDOW =
-        main_window_widget_new (zrythm_app);
+      MAIN_WINDOW = NULL;
+      ZRYTHM->event_queue = NULL;
 
       g_message ("destroying previous main "
                  "window...");
@@ -555,6 +561,13 @@ load (
   quantize_options_update_quantize_points (
     &PROJECT->quantize_opts_editor);
 
+  if (loading_while_running)
+    {
+      g_message ("recreating main window...");
+      MAIN_WINDOW =
+        main_window_widget_new (zrythm_app);
+    }
+
   /* sanity check */
   project_sanity_check (PROJECT);
 
@@ -718,14 +731,14 @@ project_get_states_dir (
  * Returns the audio dir for the given Project.
  */
 char *
-project_get_audio_dir (
+project_get_pool_dir (
   Project * self)
 {
   g_warn_if_fail (self->dir);
   return
     g_build_filename (
       self->dir,
-      PROJECT_AUDIO_DIR,
+      PROJECT_POOL_DIR,
       NULL);
 }
 
@@ -783,7 +796,11 @@ project_save (
   char * exports_dir =
     project_get_exports_dir (PROJECT);
   io_mkdir (exports_dir);
+  char * pool_dir =
+    project_get_pool_dir (PROJECT);
+  io_mkdir (pool_dir);
   g_free (exports_dir);
+  g_free (pool_dir);
 
   /* set the title */
   char * basename =
