@@ -351,9 +351,11 @@ task_completed_cb (GObject *source_object,
  *
  * This is the final step.
  */
-static void on_setup_main_window (GSimpleAction  *action,
-                             GVariant *parameter,
-                             gpointer  user_data)
+static void
+on_setup_main_window (
+  GSimpleAction  *action,
+  GVariant *parameter,
+  gpointer  user_data)
 {
   g_message ("setup main window");
 
@@ -567,6 +569,35 @@ static void on_prompt_for_project (
             S_GENERAL,
             "first-run"))
         {
+          /* warranty disclaimer */
+          GtkDialogFlags flags =
+            GTK_DIALOG_DESTROY_WITH_PARENT;
+          GtkWidget * dialog =
+            gtk_message_dialog_new (
+              NULL,
+              flags,
+              GTK_MESSAGE_INFO,
+              GTK_BUTTONS_OK,
+"Copyright (C) 2018-2019 Alexandros Theodotou\n"
+"\n"
+"Zrythm is free software: you can redistribute it and/or modify\n"
+"it under the terms of the GNU Affero General Public License as published by\n"
+"the Free Software Foundation, either version 3 of the License, or\n"
+"(at your option) any later version.\n"
+"\n"
+"Zrythm is distributed in the hope that it will be useful,\n"
+"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+"GNU Affero General Public License for more details.\n"
+"\n"
+"You should have received a copy of the GNU Affero General Public License\n"
+"along with Zrythm.  If not, see <https://www.gnu.org/licenses/>.");
+          gtk_window_set_title (
+            GTK_WINDOW (dialog),
+            _("License Information"));
+          gtk_dialog_run (GTK_DIALOG (dialog));
+          gtk_widget_destroy (dialog);
+
           first_run_assistant =
             first_run_assistant_widget_new (
               GTK_WINDOW (splash));
@@ -680,7 +711,8 @@ zrythm_app_open (
  * First function that gets called.
  */
 static void
-zrythm_app_startup (GApplication* _app)
+zrythm_app_startup (
+  GApplication* _app)
 {
   g_message ("startup");
   G_APPLICATION_CLASS (zrythm_app_parent_class)->
@@ -854,12 +886,15 @@ zrythm_app_startup (GApplication* _app)
   accel_install_primary_action_accelerator (
     "6",
     "win.audition-mode");
-  accel_install_primary_action_accelerator (
-    "KP_4",
+  accel_install_action_accelerator (
+    "KP_4", "BackSpace",
     "win.goto-prev-marker");
   accel_install_primary_action_accelerator (
     "KP_6",
     "win.goto-next-marker");
+  accel_install_primary_action_accelerator (
+    "space",
+    "win.play-pause");
   accel_install_primary_action_accelerator (
     "Q",
     "win.quick-quantize::global");
@@ -916,6 +951,7 @@ zrythm_app_init (ZrythmApp * _app)
     { "fullscreen", activate_fullscreen },
     { "chat", activate_chat },
     { "manual", activate_manual },
+    { "news", activate_news },
     { "bugreport", activate_bugreport },
     { "donate", activate_donate },
     { "iconify", activate_iconify },
