@@ -37,7 +37,7 @@ fixture_set_up (
   /* needed to set TRANSPORT */
   transport_init (TRANSPORT, 0);
   engine_update_frames_per_tick (
-    4, 140, 44000);
+    AUDIO_ENGINE, 4, 140, 44000);
 
   /*Position start_pos =*/
   /*fixture->midi_region =*/
